ParseWhile

Struct ParseWhile 

pub struct ParseWhile<F>(pub F)
where
    F: Fn(char) -> bool;
Keep parsing characters while some predicate is met. If none of the characters meet the predicate, and error will be returned. If this is not desired, try using ParseWhileOrNothing

Example

use parlib::parsers::ParseWhile;
use parlib::traits::Parser;

let parse_numbers = ParseWhile(|c| c.is_numeric());
let answer_valid = parse_numbers.parse("123a 1234");
assert_eq!(answer_valid, Ok(("123".to_string(), "a 1234".to_string())));

In the following example, and error will be returned, since none of the characters met the predicate is_numeric

use parlib::parsers::ParseWhile;
use parlib::traits::Parser;
use parlib::errors::ParsingError;

let parse_numbers = ParseWhile(|c| c.is_numeric());
let answer_bad = parse_numbers.parse("x123a 1234");
assert_eq!(
    answer_bad,
    Err(ParsingError::PatternNotFound(
        "no characters matched predicate".to_string()
    ))
);

Tuple Fields

0: F